# -*-mode: fundamental; coding: utf-8;-*-
# UTF-8 encoded Finnish translation file for use with Oddmuse
#
# Copyright (c) 2004 mixu (Mikito Takada)
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: finnish-utf8.pl,v 1.6 2005/10/09 12:48:35 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Lukeminen ei ole sallittua: käyttäjä, IP tai verkko on estetty.
Could not create %s
%s:ää ei voitu luoda
Invalid UserName %s: not saved.
Epäkelpo käyttäjännimi %s: ei tallennettu.
UserName must be 50 characters or less: not saved
Käyttäjännimen on oltava alle 50 merkkiä pitkä: ei tallennettu
This page contains an uploaded file:

XML::RSS is not available on this system.
XML::RSS ei ole asennettuna tälle palvelimelle.
diff
diff
history
historia
%s returned no data, or LWP::UserAgent is not available.
%s ei palauttanut dataa, tai LWP::UserAgent -moduuli ei ole saatavilla.
RSS parsing failed for %s
RSS-parseri epäonnistui: %s
No items found in %s.
No items found in %s.
 . . . . 

Click to edit this page
Klikkaa muokataksesi tätä sivua
image
kuva
download
download
CGI Internal error: %s

Invalid action parameter %s
Virheellinen toiminto %s
Invalid URL.
Virheellinen URL.
Page name is missing
Sivun nimi puuttuu
Page name is too long: %s
Sivun nimi on liian pitkä: %s
Invalid Page %s
Virheellinen sivu %s
Invalid Page %s (must not end with .db)
Virheellinen sivu %s (pääte ei voi olla .db)
Invalid Page %s (must not end with .lck)
Virheellinen sivu %s (pääte ei voi olla .lck)
Page name may not contain space characters: %s
Sivun nimi ei voi sisältää välilyöntejä:
Preview:
Esikatselu:
Preview only, not yet saved
Pelkkä esikatselu, sivua ei ole tallennettu vielä
Please go on to %s.
Siirtykää sivulle %s, kiitos.
Could not open %s log file
Lokitiedostoa %s ei voitu avata
Error was
Virhe oli
Note: This error is normal if no changes have been made.
Huom: Tämä virhe on normaali, jos muutoksia ei ole tehty.
Could not open old %s log file
Vanhaa lokitiedostoa %s ei voitu avata
No updates since %s
Ei päivityksiä %s jälkeen
Updates since %s
Päivitykset %s jälkeen
Updates in the last %s days
Päivitykset viimeisten %s päivän aikana
Updates in the last %s day
Päivitykset viimeisen %s päivän aikana
for %s only
vain %s:lle
List latest change per page only
Luettele viimeisimmät muutokset kullekin sivulle
List all changes
Luettele kaikki muutokset
List only major changes
Luettele vain tärkeimmät muutokset
Include minor changes
Näytä pienet korjaukset
%s days
%s päivää
List later changes
Luettele myöhemmät muutokset
Filters
Suotimet
Title:

Title and Body:

Username:
Käyttäjännimi:
Host:
Host:
Language:
Kieli:
Go!
Siirry!
(minor)
(pieni korjaus)
rollback
sivun palautus
new
uusi
from %s
%s:stä
This page is too big to send over RSS.

History of %s
%s:n historia
Compare
Vertaa
Revision %s
Versio %s
by

Rolling back changes
Sivua palautetaan
Missing target for rollback.
Palautuksen kohde puuttuu.
Target for rollback is too far back.
Palautuksen kohde on liian kaukana.
Rollback to %s
Palautus %s:ään
%s rolled back
%s palautettu
Index of all pages
Sivuston sisällysluettelo
Wiki Version
Wikin versio
Unlock Wiki
Avataan lukitus
Password
Salasana
Run maintenance
Ylläpitotoiminto
Unlock site
Avaa sivuston lukko
Lock site
Lukitse sivusto
Install CSS

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Etusivu]
redirected from %s
uudelleenohjattu sivulta %s
Click to search for references to this page
Klikkaa hakeaksesi viittauksia tälle sivulle
Cookie: 

Warning
Varoitus
Database is stored in temporary directory %s
Tietokanta on tallennettu väliaikaishakemistoon %s
%s seconds
%s sekuntia
The same page on other sites:
Sama sivu muilla sivustoilla:
EditNearLinks
MuokkaaLähiLinkkejä
Last edited
Viimeksi muokattu
Edited
Muokattu
by %s
 %s
(diff)
(diff)
Edit revision %s of this page
Muokkaa tämän sivun versiota %s
Edit this page
Muokkaa tätä sivua
e
m
This page is read-only
Tämä sivu on lukittu muutoksilta
View other revisions
Näytä muut versiot
View current revision
Näytä nykyisin versio
View all changes
Näytä kaikki muutokset
Homepage URL:
Kotisivun URL:
s
t
Save
Tallenna
Preview
Esikatselu
Search:
Haku:
f
h
Replace:
Korvaa:
Validate HTML
Tarkista HTML
Validate CSS
Tarkista CSS
Difference (from revision %1 to %2)
Muutokset (versioiden %1 ja %2 välillä)
revision %s
versio %s
current revision
nykyinen versio
Difference (from prior %s revision)
Muutokset (aiempaan versioon %s)
major
muokkaus
minor
korjaus
No diff available.
Muutoksien vertailua ei saatavilla.
The two revisions are the same.

Old revision:
Vanha versio:
Changed:
Muokattu:
Removed:
Poistettu:
Added:
Lisätty:
to

Revision %s not available
Versiota %s ei ole saatavilla
showing current revision instead
näytetään nykyinen versio sen sijaan
Showing revision %s
Näytetään versio %s
Cannot save a nameless page.
Sivua ei voi tallentaa ilman nimeä.
Cannot save a page without revision.
Sivua ei voi tallentaa ilman versiota.
Cannot open %s
Ei voitu avata: %s
Cannot write %s
Ei voitu kirjoittaa: %s
Cannot create %s

Could not get %s lock
Ei voitu lukita: %s
This operation may take several seconds...
Tämä operaatio voi kestää useita sekunteja...
Forced unlock of %s lock.
Pakotettu lukon avaus: %s.
No unlock required.
Lukon avausta ei tarvittu.
%s hours ago
%s tuntia aiemmin
1 hour ago
yhtä tuntia aiemmin
%s minutes ago
%s minuuttia aiemmin
1 minute ago
yhtä minuuttia aiemmin
%s seconds ago
%s sekuntia aiemmin
1 second ago
yhtä sekuntia aiemmin
just now
juuri nyt
Edit Denied
Muokkaus estetty
Editing not allowed: user, ip, or network is blocked.
Muokkaus estetty: käyttäjä, IP tai verkko on estetty.
Contact the wiki administrator for more information.
Ota yhteyttä wikin ylläpitoon lisätiedon tarpeessa.
The rule %s matched for you.
Sääntö %s sopi sinuun.
See %s for more information.
Katso %s lisätiedon tarpeessa.
Editing not allowed: %s is read-only.
Muokkaus estetty: %s on lukittu muutoksilta.
Only administrators can upload files.
Vain ylläpito voi tallentaa tiedostoja.
Editing revision %s of
Muokataan versiota %s /
Editing %s
Muokataan %s:ää
Editing old revision %s.
Muokataan vanhaa versiota %s.
Saving this page will replace the latest revision with this text.
Tämän sivun tallentaminen korvaa viimeisimmän version tällä tekstillä.
Summary:
Yhteenveto:
This change is a minor edit.
Tämä on pieni korjaus.
Replace this file with text.
Korvaa tämä tiedosto tekstillä.
Replace this text with a file.
Korvaa tämä teksti tiedostolla.
File to upload: 
Tallennettava tiedosto: 
Files of type %s are not allowed.
Tyyppiä %s olevat tiedostot eivät ole sallittuja.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Salasanasi tallennetaan keksiin (cookie), jos cookies-toiminto on päällä. Tallennettu cookie voi kadota, jos siirryt toiselle tietokoneelle, toiselle käyttäjäntunnukselle tai eri verkkoselaimelle.
You are currently an administrator on this site.
Olet tällä hetkellä kirjautunut sivuston ylläpitäjänä.
You are currently an editor on this site.
Olet tällä hetkellä sivuston toimittaja (editor).
You are a normal user on this site.
Olet tällä hetkellä tavallinen sivuston käyttäjä.
Your password does not match any of the  administrator or editor passwords.
Salasanasi ei ole yksikään ylläpidon tai toimittajien salasanoista.
Password:
Salasana:
This site does not use admin or editor passwords.
Tämä sivusto ei käytä ylläpidon tai toimittajien salasanoja.
This operation is restricted to site editors only...
Tämä toiminto on rajoitettu sivuston toimittajille...
This operation is restricted to administrators only...
Tämä toiminto on rajoitettu sivuston ylläpitäjille...
Rule "%1" matched "%2" on this page.
Sääntö "%1" sopi "%2":teen tällä sivulla.
Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)
(%s:lle)
Filter:

%s pages found.
%s sivua löydetty.
Replaced: %s
Korvattu: %s
Search for: %s
Etsi: %s
View changes for these pages
Näytä muutokset näille sivulle
Search sites on the %s as well
Etsi myös sivustoilla %s
and
ja
or
tai
Fetching results from %s:
Haetaan tulokset %s:stä :
Near pages:
Lähisivut:
last updated
viimeksi päivitetty
Complete Content
Sisältö
The main page is %s.
Etusivu on %s.
Comments on this page
Komentteja tähän sivuun liittyen
Editing not allowed for %s.
Muokkaus ei ole sallittu: %s.
SampleUndefinedPage
EsimerkkiSivu
%s cannot be defined.
%s ei voida määrittää
Sample_Undefined_Page
Esimerkki_Sivu
[[%s]] cannot be defined.
[[%s]] ei voida määrittää.
Only an administrator can create %s.
Vain ylläpito voi luoda %s.
Transfer Error: %s
Virhe siirrossa: %s
Browser reports no file info.
Selain ei ilmoita tiedoston tietoja.
Browser reports no file type.
Selain ei ilmoita tiedoston tyyppiä.
The page contains banned text.
Tämä sivu sisältää kielettyä tekstiä.
No changes to be saved.

This page was changed by somebody else %s.
Joku muu muokkasi tätä sivua %s.
The changes conflict.  Please check the page again.
Muutokset ovat ristiriidassa. Tarkista sivu uudelleen.
Please check whether you overwrote those changes.
Tarkista, ylikirjoititko joitakin noista muutoksista.
Anonymous
Nimetön
Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!
Sivua ei voitu lukita sulautusta varten!
you
sinä
ancestor
edeltäjä
other
muu
Run Maintenance

Maintenance not done.
Ylläpitoa ei suoritettu.
(Maintenance can only be done once every 12 hours.)
Ylläpitotoiminto voidaan suorittaa vain kerran 12 tunnissa.)
Remove the "maintain" file or wait.
Poista "maintain" -tiedosto tai odota.
Main lock obtained.
Sivuston lukitus aloitettu.
Expiring keep files and deleting pages marked for deletion
Eräännytetään keep-tiedostot ja poistetaan poistettaviksi merkityt sivut
not deleted: 
ei poistettu: 
deleted
poistettu
Moving part of the %s log file.
Siirretään osa %s lokitiedostosta.
Moving %s log entries.
Siirretään %s kirjausta.
Getting page index file for %s.
Haetaan sivun indeksitiedosto %s.
Main lock released.
Sivuston lukitus avattu.
Set or Remove global edit lock
Aseta tai poista sivuston muokkauslukitus
Edit lock created.
Muokkauslukitus asetettu.
Edit lock removed.
Muokkauslukitus poistettu.
Set or Remove page edit lock
Aseta tai poista sivun muokkauslukitus
Missing page id to lock/unlock...
Sivun id puuttu lukitusta/avausta varten...
Lock for %s created.
Lukko %s:lle luotu.
Lock for %s removed.
Lukko %s:lle poistettu.
Displaying Wiki Version

Show dependencies

Inter links:
Kaukolinkit:
Near links:
Lähilinkit:
Show parsed link data

Too many connections by %s
Liian monta yhteydenottoa %s:stä
Please do not fetch more than %1 pages in %2 seconds.
älä avaa yli %1 sivua %2 sekunnin aikana.
Check whether the web server can create the directory %s and whether it can create files in it.
Tarkista voiko www-palvelin luoda hakemiston %s ja voiko se luoda sivuja tähän hakemistoon.
anchor first defined here: %s
ankkuri nimetty ensimmäisen kerran täällä: %s
Click to search for references to this permanent anchor
Klikkaa etsiäksesi viittauksia tähän pysyvään ankkuriin
the page %s also exists
tämä sivu %s on myös olemassa
Copy one of the following stylesheets to %s:

Deleting %s
Poistetaan %s
Deleted %s
Poistettu %s
Renaming %1 to %2.
Uudelleennimetään %1:stä %2:ksi
The page %s does not exist
Sivu %s ei ole olemassa
The page %s already exists
Sivu %s on jo olemassa
Cannot rename %1 to %2

Renamed to %s
Nimi vaihdettu %:ksi
Renamed from %s
Nimi muutettu %s:stä
Renamed %1 to %2.
Nimi vaihdettu %1:stä %2:ksi
Immediately delete %s

Rename %s to:

Cannot highlight the language %s.
Kieltä %s ei voida merkitä
Recent Visitors
Viimeisimmät vierailijat
some action

was here

and read

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
Yksi seuraavista tarvitaan kalenterin luomiseksi: cal(1), Date::Calc(3), or Date::Pcalc(3).
The match parameter is missing.
Hakuparametri puuttuu.
Page Collection for %s
Sivukokoelma %s
Previous
Edellinen
Next
Seuraava
Calendar %s
Kalenteri %s
Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages
Sivuja puhdistetaan spam:ista
Cannot find revision %s.
Versiota ei löydy %s.
Revert to revision %1: %2
Palauta versioon %1: %2
Marked as %s.
Merkitty nimellä %s.
Cannot find unspammed revision.
Spam-vapaata versiota ei löydy.
Add Comment

ordinary changes

Footnotes:
Alaviitteet:
Could not find %1.html template in %2

Only Editors are allowed to see hidden pages.

Only Admins are allowed to see hidden pages.

image: %s
kuva: %s
Index
Sisällysluettelo
Languages:
Kielet:
Show!
Näytä
Define
Määritä
Full Link List
Täysi linkkilista
Template without parameters
Pohja ilman parametrejä
The template %s is either empty or does not exist.
Pohja %s on joko tyhjä tai ei ole olemassa.
Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

  Please allow time for the webmaster to approve your request.

  An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

<p>Logout of %s?</p>

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s

The username "%s" does not exist.

Reset Password for %s

<p>Reset Password?</p>

Change Password for %s

<p>Change Password?</p>

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

Clearing Cache
Välimuistia tyhjennetään
Done.

Generating Link Database
Linkkitietokantaa luodaan
The 404 handler extension requires the link data extension (links.pl).
404-käsittelijä-laajennus vaatii "link data" -laajennuksen (links.pl).
LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List
Orpojen sivujen lista
Trail: 
Historia: 
None
Ei yhtään
Type
Tyyppi
Permalink to "%s"
Pysyvä linkki "%s":ään
Portrait
Avatar
You did not answer correctly.

All Referrers
Kaikki viittaukset
Referrers
Viittaukset
Rebuild index for searching

Rebuilding Index

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

Search term missing.

Result pages: 

(%s results)

Slideshow:%s

Static Copy
Staattinen kopio
Back to %s
Takaisin %s:ään
Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Tag

Alternatively, use one of the following templates:
Vaihtoehtoisesti, käytä yhtä seuraavista pohjista:
Thread: %s
Säie: %s
ID parameter is missing.
ID-parametri puuttuu.
Thread %s does not exist.
Säie %s ei ole olemassa.
Page %s does not contain a thread.
Sivu %s ei sisällä säiettä.
Add
Lisää
URL parameter is missing.
URL-parametri puuttuu.
Add to %s thread
Lisää %s säikeeseen
Below:
Alla:
URL:
URL:
Name:
Nimi:
Failed to remove %s
%s:n poisto epäonnistui
Contents
Sisältö
This page is a translation of %s. 

The translation is up to date.
Käännös on ajantasainen.
The translation is outdated.
Käännös on vanhentunut.
The page does not exist.
Sivu ei ole olemassa.
http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.com/exec/obidos/ISBN=%s
alternate
vaihtoehto
http://www.pricescan.com/books/BookDetail.asp?isbn=%s
http://www.pricescan.com/books/BookDetail.asp?isbn=%s
search
haku
Upload of %s file

Blog
Blog
Matching pages:

New

Edit %s.

END_OF_TRANSLATION
